---
feature_story: FS_44_36_84_88
feature_title: consume args one by one
feature_status: TEST
---

This feature trades performance for consistency:
*   instead of consuming as many user input args matching enums obtained in a previous query,
*   consume only one user input arg at a time and re-query before next consumption.

The feature ensures:
*   FS_51_67_38_37: avoid impossible arg combinations

It is expected that number of queries per request will grow (increasing response time),
but the matching results are less confusing.

The feature determines behavior for cases like:
*   TD_99_99_88_75 mutually exclusive `prop_name`-s from diff `prop_value`-s

See also:
*   FS_76_29_13_28: `command_arg` consumption priority
